==> zio-aws-opensearch_2.13-5.17.172.2-sources.jar: zio/aws/opensearch/model/DomainEndpointOptions.scala <==
package zio.aws.opensearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.opensearch.model.primitives.{ARN, DomainNameFqdn}
import scala.jdk.CollectionConverters._
final case class DomainEndpointOptions(
    enforceHTTPS: Optional[Boolean] = Optional.Absent,
    tlsSecurityPolicy: Optional[zio.aws.opensearch.model.TLSSecurityPolicy] =
      Optional.Absent,
    customEndpointEnabled: Optional[Boolean] = Optional.Absent,
    customEndpoint: Optional[DomainNameFqdn] = Optional.Absent,
    customEndpointCertificateArn: Optional[ARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions = {
    import DomainEndpointOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions
      .builder()
      .optionallyWith(enforceHTTPS.map(value => value: java.lang.Boolean))(
        _.enforceHTTPS
      )
      .optionallyWith(tlsSecurityPolicy.map(value => value.unwrap))(
        _.tlsSecurityPolicy
      )
      .optionallyWith(
        customEndpointEnabled.map(value => value: java.lang.Boolean)
      )(_.customEndpointEnabled)
      .optionallyWith(
        customEndpoint.map(value =>
          DomainNameFqdn.unwrap(value): java.lang.String
        )
      )(_.customEndpoint)
      .optionallyWith(
        customEndpointCertificateArn.map(value =>
          ARN.unwrap(value): java.lang.String
        )
      )(_.customEndpointCertificateArn)
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.DomainEndpointOptions.ReadOnly =
    zio.aws.opensearch.model.DomainEndpointOptions.wrap(buildAwsValue())
}
object DomainEndpointOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.DomainEndpointOptions =
      zio.aws.opensearch.model.DomainEndpointOptions(
        enforceHTTPS.map(value => value),
        tlsSecurityPolicy.map(value => value),
        customEndpointEnabled.map(value => value),
        customEndpoint.map(value => value),
        customEndpointCertificateArn.map(value => value)
      )
    def enforceHTTPS: Optional[Boolean]
    def tlsSecurityPolicy: Optional[zio.aws.opensearch.model.TLSSecurityPolicy]
    def customEndpointEnabled: Optional[Boolean]
    def customEndpoint: Optional[DomainNameFqdn]
    def customEndpointCertificateArn: Optional[ARN]
    def getEnforceHTTPS: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enforceHTTPS", enforceHTTPS)
    def getTlsSecurityPolicy
        : ZIO[Any, AwsError, zio.aws.opensearch.model.TLSSecurityPolicy] =
      AwsError.unwrapOptionField("tlsSecurityPolicy", tlsSecurityPolicy)
    def getCustomEndpointEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("customEndpointEnabled", customEndpointEnabled)
    def getCustomEndpoint: ZIO[Any, AwsError, DomainNameFqdn] =
      AwsError.unwrapOptionField("customEndpoint", customEndpoint)
    def getCustomEndpointCertificateArn: ZIO[Any, AwsError, ARN] =
      AwsError.unwrapOptionField(
        "customEndpointCertificateArn",
        customEndpointCertificateArn
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions
  ) extends zio.aws.opensearch.model.DomainEndpointOptions.ReadOnly {
    override val enforceHTTPS: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enforceHTTPS())
      .map(value => value: Boolean)
    override val tlsSecurityPolicy
        : Optional[zio.aws.opensearch.model.TLSSecurityPolicy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tlsSecurityPolicy())
        .map(value => zio.aws.opensearch.model.TLSSecurityPolicy.wrap(value))
    override val customEndpointEnabled: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customEndpointEnabled())
        .map(value => value: Boolean)
    override val customEndpoint: Optional[DomainNameFqdn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customEndpoint())
        .map(value => zio.aws.opensearch.model.primitives.DomainNameFqdn(value))
    override val customEndpointCertificateArn: Optional[ARN] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customEndpointCertificateArn())
        .map(value => zio.aws.opensearch.model.primitives.ARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions
  ): zio.aws.opensearch.model.DomainEndpointOptions.ReadOnly = new Wrapper(impl)
}

==> zio-aws-opensearch_3-5.17.202.1-sources.jar: zio/aws/opensearch/model/DomainEndpointOptions.scala <==
package zio.aws.opensearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.opensearch.model.primitives.{ARN, DomainNameFqdn}
import scala.jdk.CollectionConverters.*
final case class DomainEndpointOptions(
    enforceHTTPS: Optional[Boolean] = Optional.Absent,
    tlsSecurityPolicy: Optional[zio.aws.opensearch.model.TLSSecurityPolicy] =
      Optional.Absent,
    customEndpointEnabled: Optional[Boolean] = Optional.Absent,
    customEndpoint: Optional[DomainNameFqdn] = Optional.Absent,
    customEndpointCertificateArn: Optional[ARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions = {
    import DomainEndpointOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions
      .builder()
      .optionallyWith(enforceHTTPS.map(value => value: java.lang.Boolean))(
        _.enforceHTTPS
      )
      .optionallyWith(tlsSecurityPolicy.map(value => value.unwrap))(
        _.tlsSecurityPolicy
      )
      .optionallyWith(
        customEndpointEnabled.map(value => value: java.lang.Boolean)
      )(_.customEndpointEnabled)
      .optionallyWith(
        customEndpoint.map(value =>
          DomainNameFqdn.unwrap(value): java.lang.String
        )
      )(_.customEndpoint)
      .optionallyWith(
        customEndpointCertificateArn.map(value =>
          ARN.unwrap(value): java.lang.String
        )
      )(_.customEndpointCertificateArn)
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.DomainEndpointOptions.ReadOnly =
    zio.aws.opensearch.model.DomainEndpointOptions.wrap(buildAwsValue())
}
object DomainEndpointOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.DomainEndpointOptions =
      zio.aws.opensearch.model.DomainEndpointOptions(
        enforceHTTPS.map(value => value),
        tlsSecurityPolicy.map(value => value),
        customEndpointEnabled.map(value => value),
        customEndpoint.map(value => value),
        customEndpointCertificateArn.map(value => value)
      )
    def enforceHTTPS: Optional[Boolean]
    def tlsSecurityPolicy: Optional[zio.aws.opensearch.model.TLSSecurityPolicy]
    def customEndpointEnabled: Optional[Boolean]
    def customEndpoint: Optional[DomainNameFqdn]
    def customEndpointCertificateArn: Optional[ARN]
    def getEnforceHTTPS: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enforceHTTPS", enforceHTTPS)
    def getTlsSecurityPolicy
        : ZIO[Any, AwsError, zio.aws.opensearch.model.TLSSecurityPolicy] =
      AwsError.unwrapOptionField("tlsSecurityPolicy", tlsSecurityPolicy)
    def getCustomEndpointEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("customEndpointEnabled", customEndpointEnabled)
    def getCustomEndpoint: ZIO[Any, AwsError, DomainNameFqdn] =
      AwsError.unwrapOptionField("customEndpoint", customEndpoint)
    def getCustomEndpointCertificateArn: ZIO[Any, AwsError, ARN] =
      AwsError.unwrapOptionField(
        "customEndpointCertificateArn",
        customEndpointCertificateArn
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions
  ) extends zio.aws.opensearch.model.DomainEndpointOptions.ReadOnly {
    override val enforceHTTPS: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enforceHTTPS())
      .map(value => value: Boolean)
    override val tlsSecurityPolicy
        : Optional[zio.aws.opensearch.model.TLSSecurityPolicy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tlsSecurityPolicy())
        .map(value => zio.aws.opensearch.model.TLSSecurityPolicy.wrap(value))
    override val customEndpointEnabled: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customEndpointEnabled())
        .map(value => value: Boolean)
    override val customEndpoint: Optional[DomainNameFqdn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customEndpoint())
        .map(value => zio.aws.opensearch.model.primitives.DomainNameFqdn(value))
    override val customEndpointCertificateArn: Optional[ARN] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customEndpointCertificateArn())
        .map(value => zio.aws.opensearch.model.primitives.ARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.DomainEndpointOptions
  ): zio.aws.opensearch.model.DomainEndpointOptions.ReadOnly = new Wrapper(impl)
}
